==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/Custom-SplitCard.dart <==
/*
Description:
A card with an Image covering the upper part, and a title and subtitle.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'Custom-SplitCard.dart';

Usage:
-Creating the object for the card

    onclickCardBtn(int nIndex, String sText) {print(nIndex);print(sText);}
    MaterialCardData Obj1 = new MaterialCardData(
        title: "Colosseum",
        subtitle: "The Colosseum in Rome was built in the first century by order of the Emperor Vespasian",
        containerHeight: 300.0,
        containerDecoration: BoxDecoration(
          color: Colors.grey,
          border: Border.all(
            color: Colors.black,
            width: 1.0,
          ),
          borderRadius:
          BorderRadius.circular(15),
        ),
        textStyle1: TextStyle(
          color: Colors.black,
          fontSize: 20,
          fontWeight: FontWeight.bold,
        ),
        textStyle2: TextStyle(
          color: Colors.black,
          fontSize: 16.0,
        ),
        imgType: "Network",
        imgPath: "https://cdn.britannica.com/75/75775-050-1FC4B34B/Colosseum-Rome.jpg");


    -Object call for the widget
        body: FiftyCardWidget(Obj1, onclickCardBtn),


*/


import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';


Widget FiftyCardWidget(MaterialCardData data, void Function(int, String) callback) {
    ImageProvider image;
    if(data.imgType == "Network"){
      image=NetworkImage(data.imgPath);
    }
    else{
      image=AssetImage(data.imgPath);
    }
  return Container(
    width: (data.containerWidth != null) ? data.containerWidth : constants.heightThreeHundred,
  height:  (data.containerHeight != null) ? data.containerHeight : constants.heightThreeHundred,
  decoration: (data.containerDecoration != null) ? data.containerDecoration : BoxDecoration(
      color: MediumGreyThemeData().accentColor,
      border: Border.all(
        color: MediumGreyThemeData().primaryColorDark,
        width: constants.heightOne,
      ),
      borderRadius:
      BorderRadius.circular(constants.heightFive * constants.heightThree),
    ),
    child: Column(
      children: <Widget>[
        Container(
          decoration: (data.imgDecoration != null) ? data.imgDecoration : BoxDecoration(
            color: MediumGreyThemeData().backgroundColor,
            borderRadius: BorderRadius.all(Radius.circular(constants.heightTen)),
          ),
          child: Container(
            height: constants.heightTwoHundred,
            decoration: BoxDecoration(
              image: DecorationImage(
                image: (image != null) ? image : NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png"),
              ),
            ),
          ),
        ),

        Padding(
          padding: EdgeInsets.only(top: 10),
          child: Column(
            children: <Widget>[
              ListTile(
                title: Text(
                  (data.title != null) ? data.title : constants.cardTitle,
                  style: (data.textStyle1 != null) ? data.textStyle1 : TextStyle(
                    color: MediumGreyThemeData().textSelectionColor,
                    fontSize: constants.heightTwenty,
                    fontWeight: constants.fontBold,
                  ),
                  overflow: TextOverflow.ellipsis,
                ),
                subtitle: Text(
                  (data.subtitle != null) ? data.subtitle : constants.cardSubtitle,
                  style: (data.textStyle2 != null) ? data.textStyle2 : TextStyle(
                    color: MediumGreyThemeData().primaryColorDark,
                    fontSize: constants.heightTwenty,
                  ),
                  overflow: TextOverflow.ellipsis,
                  maxLines: constants.maxLines,
                  softWrap: true,
                ),
              ),
            ],
          ),
        ),
      ],
    ),
  );
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/Custom-SplitCard.dart <==
/*
Description:
A card with an Image covering the upper part, and a title and subtitle.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'Custom-SplitCard.dart';

Usage:
-Creating the object for the card

    onclickCardBtn(int nIndex, String sText) {print(nIndex);print(sText);}
    MaterialCardData Obj1 = new MaterialCardData(
        title: "Colosseum",
        subtitle: "The Colosseum in Rome was built in the first century by order of the Emperor Vespasian",
        containerHeight: 300.0,
        containerDecoration: BoxDecoration(
          color: Colors.grey,
          border: Border.all(
            color: Colors.black,
            width: 1.0,
          ),
          borderRadius:
          BorderRadius.circular(15),
        ),
        textStyle1: TextStyle(
          color: Colors.black,
          fontSize: 20,
          fontWeight: FontWeight.bold,
        ),
        textStyle2: TextStyle(
          color: Colors.black,
          fontSize: 16.0,
        ),
        imgType: "Network",
        imgPath: "https://cdn.britannica.com/75/75775-050-1FC4B34B/Colosseum-Rome.jpg");


    -Object call for the widget
        body: fiftyCardWidget(Obj1, onclickCardBtn),


*/


import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';


Widget fiftyCardWidget(MaterialCardData data, void Function(int, String) callback) {
    ImageProvider image;
    if(data.imgType == "Network"){
      image=NetworkImage(data.imgPath);
    }
    else{
      image=AssetImage(data.imgPath);
    }
  return Container(
    width: (data.containerWidth != null) ? data.containerWidth : constants.heightThreeHundred,
  height:  (data.containerHeight != null) ? data.containerHeight : constants.heightThreeHundred,
  decoration: (data.containerDecoration != null) ? data.containerDecoration : BoxDecoration(
      color: mediumGreyThemeData().accentColor,
      border: Border.all(
        color: mediumGreyThemeData().primaryColorDark,
        width: constants.heightOne,
      ),
      borderRadius:
      BorderRadius.circular(constants.heightFive * constants.heightThree),
    ),
    child: Column(
      children: <Widget>[
        Container(
          decoration: (data.imgDecoration != null) ? data.imgDecoration : BoxDecoration(
            color: mediumGreyThemeData().backgroundColor,
            borderRadius: BorderRadius.all(Radius.circular(constants.heightTen)),
          ),
          child: Container(
            height: constants.heightTwoHundred,
            decoration: BoxDecoration(
              image: DecorationImage(
                image: (image != null) ? image : NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png"),
              ),
            ),
          ),
        ),

        Padding(
          padding: EdgeInsets.only(top: 10),
          child: Column(
            children: <Widget>[
              ListTile(
                title: Text(
                  (data.title != null) ? data.title : constants.cardTitle,
                  style: (data.textStyle1 != null) ? data.textStyle1 : TextStyle(
                    color: mediumGreyThemeData().textSelectionColor,
                    fontSize: constants.heightTwenty,
                    fontWeight: constants.fontBold,
                  ),
                  overflow: TextOverflow.ellipsis,
                ),
                subtitle: Text(
                  (data.subtitle != null) ? data.subtitle : constants.cardSubtitle,
                  style: (data.textStyle2 != null) ? data.textStyle2 : TextStyle(
                    color: mediumGreyThemeData().primaryColorDark,
                    fontSize: constants.heightTwenty,
                  ),
                  overflow: TextOverflow.ellipsis,
                  maxLines: constants.maxLines,
                  softWrap: true,
                ),
              ),
            ],
          ),
        ),
      ],
    ),
  );
}
